# myterial
Just an easy way to access material colors' hex codes

### Installation
```
pip install myterial
```


### Usage
```python
from myterial import salmon
```

To see all colors run `show_colors.py`

<img src='colors_terminal.png' width="1200px"></img>


### Colors:
<img src='colors.PNG' width="600px"></img>
